==> aroundme_0_7_0.zip: aroundme_0_7_0/aroundme/components/core/language/1/barnraiser_01/register.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/me_common.inc.php');


// ERROR MESSAGES
$lang['error']['captcha_wrong'] = 					"Your captcha word does not match the original. Please try again.";
$lang['error']['email_invalid'] = 					"You have not entered a valid email address.";
$lang['error']['email_in_use'] = 					"This email address is already in use.";
$lang['error']['firstname_empty'] = 				"You have not entered a firstname.";
$lang['error']['language_empty'] = 					"You have to at least select one language that you can read.";



// HEADERS
$lang['hdr_reg_complete'] = 					"registration complete";
$lang['hdr_intro'] = 							"join us";
$lang['hdr_register'] = 						"sign up!";
$lang['hdr_endorsement'] = 						"invited by";

// BODY TEXT
$lang['txt_welcome'] = 							"welcome";
$lang['txt_firstname'] = 						"Firstname";
$lang['txt_email'] = 							"Email";
$lang['txt_password'] = 						"Password";
$lang['txt_lang'] = 							"Which is your preferred language?";
$lang['txt_lang_selection'] = 					"Which languages can you read?";
$lang['txt_captcha_intro'] = 					"Please type the characters that you see below.";
$lang['txt_reg_legal'] = 						"I agree to observe the rules stipulated in our <a href=\"structure.php\">policy</a>.";
$lang['txt_reg_complete'] =						"An email has been sent to you with a link and a code in it. Copy your code and open the link in a browser to verify your email address and complete registration.";
$lang['txt_intro']	=							"Become a member of our network. Simply fill in the form to the right to sign up.";

// FORM
$lang['sub_register'] = 						"sign me up NOW!";


// MESSAGES AND EMAIL
$lang['subject_complete_registration'] = 		"Complete your registration!";


?>

==> aroundme_0_7_5.zip: aroundme_0_7_5/aroundme/components/core/language/1/barnraiser_01/register.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/me_common.inc.php');


// ERROR MESSAGES
$lang['error']['captcha_wrong'] = 					"Your captcha word does not match the original. Please try again.";
$lang['error']['email_invalid'] = 					"You have not entered a valid email address.";
$lang['error']['email_in_use'] = 					"This email address is already in use.";
$lang['error']['firstname_empty'] = 				"You have not entered a firstname.";
$lang['error']['language_empty'] = 					"You have to at least select one language that you can read.";



// HEADERS
$lang['hdr_reg_complete'] = 					"registration complete";
$lang['hdr_intro'] = 							"join us";
$lang['hdr_register'] = 						"sign up!";
$lang['hdr_endorsement'] = 						"invited by";

// BODY TEXT
$lang['txt_welcome'] = 							"welcome";
$lang['txt_firstname'] = 						"Firstname";
$lang['txt_email'] = 							"Email";
$lang['txt_password'] = 						"Password";
$lang['txt_lang'] = 							"Which is your preferred language?";
$lang['txt_lang_selection'] = 					"Which languages can you read?";
$lang['txt_captcha_intro'] = 					"Please type the characters that you see below.";
$lang['txt_reg_legal'] = 						"I agree to observe the rules stipulated in our <a href=\"index.php?amn=core_structure\">policy</a>.";
$lang['txt_reg_complete'] =						"An email has been sent to you with a link and a code in it. Copy your code and open the link in a browser to verify your email address and complete registration.";
$lang['txt_intro']	=							"Become a member of our network. Simply fill in the form to the right to sign up.";

// FORM
$lang['sub_register'] = 						"sign me up NOW!";


// MESSAGES AND EMAIL
$lang['subject_complete_registration'] = 		"Complete your registration!";


?>
